KeyPathFrom

Struct KeyPathFrom 

pub struct KeyPathFrom<Root> {
    pub path: Vec<KeyPathElement>,
    /* private fields */
}
Partially erased keypath, retaining information about the root type, but erasing the value type

Fields

path: Vec<KeyPathElement>

Implementations

Source

impl<Root> KeyPathFrom<Root>

pub fn prepending<Base>( &self, keypath: &KeyPath<Base, Root>, ) -> KeyPathFrom<Base>

pub fn is_subpath_of(&self, other: &Self) -> bool

Returns whether this subpath is fully contained within other.

In other words, whether other references a field/index/variant within self.

Returns false if both paths are equal.

pub fn downcast<T>(&self) -> KeyPath<Root, T>

Downcast this keypath to include value type. Note that this always succeeds, regardless of the actual value type the path is pointing to, use with caution.