pub struct KeyPathFrom<Root> {
pub path: Vec<KeyPathElement>,
/* private fields */
}Expand description
Partially erased keypath, retaining information about the root type, but erasing the value type
Fields
path: Vec<KeyPathElement>Implementations
Sourceimpl<Root> KeyPathFrom<Root>
impl<Root> KeyPathFrom<Root>
pub fn prepending<Base>( &self, keypath: &KeyPath<Base, Root>, ) -> KeyPathFrom<Base>
Sourcepub fn is_subpath_of(&self, other: &Self) -> bool
pub fn is_subpath_of(&self, other: &Self) -> bool
Returns whether this subpath is fully contained within other.
In other words, whether other references a field/index/variant within
self.
Returns false if both paths are equal.